# coding: utf-8

"""
    Mentortools Team Member Server

    Mentortools service for Team Members

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, conlist
from team_member_server_sdk.models.validation_error import ValidationError

class HTTPValidationError(BaseModel):
    """
    HTTPValidationError
    """
    detail: Optional[conlist(ValidationError)] = None
    __properties = ["detail"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> HTTPValidationError:
        """Create an instance of HTTPValidationError from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in detail (list)
        _items = []
        if self.detail:
            for _item in self.detail:
                if _item:
                    _items.append(_item.to_dict())
            _dict['detail'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> HTTPValidationError:
        """Create an instance of HTTPValidationError from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return HTTPValidationError.parse_obj(obj)

        _obj = HTTPValidationError.parse_obj({
            "detail": [ValidationError.from_dict(_item) for _item in obj.get("detail")] if obj.get("detail") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Mentortools Team Member Server

    Mentortools service for Team Members

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from team_member_server_sdk.models.wrapped_response_list_team_member_response import WrappedResponseListTeamMemberResponse  # noqa: E501

class TestWrappedResponseListTeamMemberResponse(unittest.TestCase):
    """WrappedResponseListTeamMemberResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WrappedResponseListTeamMemberResponse:
        """Test WrappedResponseListTeamMemberResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WrappedResponseListTeamMemberResponse`
        """
        model = WrappedResponseListTeamMemberResponse()  # noqa: E501
        if include_optional:
            return WrappedResponseListTeamMemberResponse(
                done = True,
                result = [
                    team_member_server_sdk.models.team_member_response.TeamMemberResponse(
                        id = 56, 
                        portal_id = 56, 
                        team_member_role_id = 56, 
                        invited_email = '', 
                        invited_code = '', 
                        invited_at = 56, 
                        last_email_sent_at = 56, 
                        activated_at = 56, 
                        enabled_at = 56, 
                        portal_member = null, )
                    ]
            )
        else:
            return WrappedResponseListTeamMemberResponse(
                result = [
                    team_member_server_sdk.models.team_member_response.TeamMemberResponse(
                        id = 56, 
                        portal_id = 56, 
                        team_member_role_id = 56, 
                        invited_email = '', 
                        invited_code = '', 
                        invited_at = 56, 
                        last_email_sent_at = 56, 
                        activated_at = 56, 
                        enabled_at = 56, 
                        portal_member = null, )
                    ],
        )
        """

    def testWrappedResponseListTeamMemberResponse(self):
        """Test WrappedResponseListTeamMemberResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Team Member Server

    Mentortools service for Team Members

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from team_member_server_sdk.api.server_requests_api import ServerRequestsApi  # noqa: E501


class TestServerRequestsApi(unittest.IsolatedAsyncioTestCase):
    """ServerRequestsApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = ServerRequestsApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_activate_team_member_v1_team_member_activate_post(self) -> None:
        """Test case for activate_team_member_v1_team_member_activate_post

        Activate Team Member  # noqa: E501
        """
        pass

    async def test_get_team_member_access_v1_team_member_access_get_post(self) -> None:
        """Test case for get_team_member_access_v1_team_member_access_get_post

        Get Team Member access  # noqa: E501
        """
        pass

    async def test_get_team_members_v1_team_member_list_post(self) -> None:
        """Test case for get_team_members_v1_team_member_list_post

        Get Team Members  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
